==> BayesianFROC_0.1.1.tar.gz: BayesianFROC/R/install_imports.R <==
#'@inheritParams fit_Bayesian_FROC

#' @title   Installer.
#'@description    This is an installer for  required packages in this package.
#  @export install_dependencies
#'To install this package BayesianFROC, we use the package xlsx which require the Java. So, if use buy a new computer and and it does not have installed the Java, then please install Java.




# devtools::document()
install_imports <-function(){
  #
  # tryCatch({
  #   library(knitr)
  # }, error = function(e) {
  #   install.packages("knitr")
  #   library(knitr)
  # })
  #
  #
  # if("knitr" %in% installed.packages()[,1]){
  #   library(knitr)
  # }else{
  #   install.packages("knitr")
  #   library(knitr)
  # }
  # ##########################################################
  #
  #
  # tryCatch({
  #   library(rstan)
  # }, error = function(e) {
  #   install.packages("rstan")
  #   library(rstan)
  # })
  #
  #
  # if("rstan" %in% installed.packages()[,1]){
  #   library(rstan)
  # }else{
  #   install.packages("rstan")
  #   library(rstan)
  # }
  #
  # ########################################################
  #
  #
  # tryCatch({
  #   library(readxl)
  # }, error = function(e) {
  #   install.packages("readxl")
  #   library(readxl)
  # })
  #
  #
  # if("readxl" %in% installed.packages()[,1]){
  #   library(readxl)
  # }else{
  #   install.packages("readxl")
  #   library(readxl)
  # }
  #
  # #############################################
  #
  #
  # #############################################
  #
  #
  # tryCatch({
  #   library(openxlsx)
  # }, error = function(e) {
  #   install.packages("openxlsx")
  #   library(openxlsx)
  # })
  #
  #
  # if("openxlsx" %in% installed.packages()[,1]){
  #   library(openxlsx)
  # }else{
  #   install.packages("openxlsx")
  #   library(openxlsx)
  # }
  #
  # #############################################
  #
  #
  #
  #
  # tryCatch({
  #   library(xlsx)
  # }, error = function(e) {
  #   install.packages("xlsx")
  #   library(xlsx)
  # })
  # ##To install this package BayesianFROC, we use the package xlsx which require the Java. So, if use buy a new computer and and it does not have installed the Java, then please install Java.

  #
  # if("xlsx" %in% installed.packages()[,1]){
  #   library(xlsx)
  # }else{
  #   install.packages("xlsx")
  #   library(xlsx)
  # }
  #
  # #############################################
  #
  #
  #
  # tryCatch({
  #   library(gridExtra)
  # }, error = function(e) {
  #   install.packages("gridExtra")
  #   library(gridExtra)
  # })
  #
  #
  # if("gridExtra" %in% installed.packages()[,1]){
  #   library(gridExtra)
  # }else{
  #   install.packages("gridExtra")
  #   library(gridExtra)
  # }

  #############################################
}#function

==> BayesianFROC_0.1.2.tar.gz: BayesianFROC/R/install_imports.R <==
#'@inheritParams fit_Bayesian_FROC

#' @title   Installer.
#'@description    This is an installer for  required packages in this package.
#  @export install_dependencies
#'To install this package BayesianFROC, we use the package xlsx which require the Java. So, if use buy a new computer and and it does not have installed the Java, then please install Java.




# devtools::document()
install_imports <-function(){




  # ##########################################################
  #
  #
  # tryCatch({
  #   library(spelling)
  # }, error = function(e) {
  #   install.packages("spelling")
  #   library(spelling)
  # })
  #
  #
  # if("spelling" %in% installed.packages()[,1]){
  #   library(spelling)
  # }else{
  #   install.packages("spelling")
  #   library(spelling)
  # }
  #
  # ########################################################














  # ##########################################################
  #
  #
  # tryCatch({
  #   library(usethis)
  # }, error = function(e) {
  #   install.packages("usethis")
  #   library(usethis)
  # })
  #
  #
  # if("usethis" %in% installed.packages()[,1]){
  #   library(usethis)
  # }else{
  #   install.packages("usethis")
  #   library(usethis)
  # }
  #
  # ########################################################





  # ##########################################################
  #
  #
  # tryCatch({
  #   library(devtools)
  # }, error = function(e) {
  #   install.packages("devtools")
  #   library(devtools)
  # })
  #
  #
  # if("devtools" %in% installed.packages()[,1]){
  #   library(devtools)
  # }else{
  #   install.packages("devtools")
  #   library(devtools)
  # }
  #
  # ####################
  #
  # tryCatch({
  #   library(knitr)
  # }, error = function(e) {
  #   install.packages("knitr")
  #   library(knitr)
  # })
  #
  #
  # if("knitr" %in% installed.packages()[,1]){
  #   library(knitr)
  # }else{
  #   install.packages("knitr")
  #   library(knitr)
  # }
  # ##########################################################
  #
  #
  # tryCatch({
  #   library(rstan)
  # }, error = function(e) {
  #   install.packages("rstan")
  #   library(rstan)
  # })
  #
  #
  # if("rstan" %in% installed.packages()[,1]){
  #   library(rstan)
  # }else{
  #   install.packages("rstan")
  #   library(rstan)
  # }
  #
  # ########################################################
  #
  #
  # tryCatch({
  #   library(readxl)
  # }, error = function(e) {
  #   install.packages("readxl")
  #   library(readxl)
  # })
  #
  #
  # if("readxl" %in% installed.packages()[,1]){
  #   library(readxl)
  # }else{
  #   install.packages("readxl")
  #   library(readxl)
  # }
  #
  # #############################################
  #
  #
  # #############################################
  #
  #
  # tryCatch({
  #   library(openxlsx)
  # }, error = function(e) {
  #   install.packages("openxlsx")
  #   library(openxlsx)
  # })
  #
  #
  # if("openxlsx" %in% installed.packages()[,1]){
  #   library(openxlsx)
  # }else{
  #   install.packages("openxlsx")
  #   library(openxlsx)
  # }
  #
  # #############################################
  #
  #
  #
  #
  # tryCatch({
  #   library(xlsx)
  # }, error = function(e) {
  #   install.packages("xlsx")
  #   library(xlsx)
  # })
  # ##To install this package BayesianFROC, we use the package xlsx which require the Java. So, if use buy a new computer and and it does not have installed the Java, then please install Java.

  #
  # if("xlsx" %in% installed.packages()[,1]){
  #   library(xlsx)
  # }else{
  #   install.packages("xlsx")
  #   library(xlsx)
  # }
  #
  # #############################################
  #
  #
  #
  # tryCatch({
  #   library(gridExtra)
  # }, error = function(e) {
  #   install.packages("gridExtra")
  #   library(gridExtra)
  # })
  #
  #
  # if("gridExtra" %in% installed.packages()[,1]){
  #   library(gridExtra)
  # }else{
  #   install.packages("gridExtra")
  #   library(gridExtra)
  # }

  #############################################













  #
  #
  # tryCatch({
  #   library(knitr)
  # }, error = function(e) {
  #   install.packages("knitr")
  #   library(knitr)
  # })
  #
  #
  # if("knitr" %in% installed.packages()[,1]){
  #   library(knitr)
  # }else{
  #   install.packages("knitr")
  #   library(knitr)
  # }

  #############################################





  #
  #
  # tryCatch({
  #   library(roxygen2)
  # }, error = function(e) {
  #   install.packages("roxygen2")
  #   library(roxygen2)
  # })
  #
  #
  # if("roxygen2" %in% installed.packages()[,1]){
  #   library(roxygen2)
  # }else{
  #   install.packages("roxygen2")
  #   library(roxygen2)
  # }

  #############################################



  #
  #
  # tryCatch({
  #   library(readxl)
  # }, error = function(e) {
  #   install.packages("readxl")
  #   library(readxl)
  # })
  #
  #
  # if("readxl" %in% installed.packages()[,1]){
  #   library(readxl)
  # }else{
  #   install.packages("readxl")
  #   library(readxl)
  # }

  #############################################




  #
  #
  # tryCatch({
  #   library(openxlsx)
  # }, error = function(e) {
  #   install.packages("openxlsx")
  #   library(openxlsx)
  # })
  #
  #
  # if("openxlsx" %in% installed.packages()[,1]){
  #   library(openxlsx)
  # }else{
  #   install.packages("openxlsx")
  #   library(openxlsx)
  # }

  #############################################






  #
  #
  # tryCatch({
  #   library(xlsx)
  # }, error = function(e) {
  #   install.packages("xlsx")
  #   library(xlsx)
  # })
  #
  #
  # if("xlsx" %in% installed.packages()[,1]){
  #   library(xlsx)
  # }else{
  #   install.packages("xlsx")
  #   library(xlsx)
  # }

  #############################################







  #
  #
  # tryCatch({
  #   library(rstantools)
  # }, error = function(e) {
  #   install.packages("rstantools")
  #   library(rstantools)
  # })
  #
  #
  # if("rstantools" %in% installed.packages()[,1]){
  #   library(rstantools)
  # }else{
  #   install.packages("rstantools")
  #   library(rstantools)
  # }

  #############################################







  #
  #
  # tryCatch({
  #   library(car)
  # }, error = function(e) {
  #   install.packages("car")
  #   library(car)
  # })
  #
  #
  # if("car" %in% installed.packages()[,1]){
  #   library(car)
  # }else{
  #   install.packages("car")
  #   library(car)
  # }

  #############################################




  #
  #
  # tryCatch({
  #   library(hexbin)
  # }, error = function(e) {
  #   install.packages("hexbin")
  #   library(hexbin)
  # })
  #
  #
  # if("hexbin" %in% installed.packages()[,1]){
  #   library(hexbin)
  # }else{
  #   install.packages("hexbin")
  #   library(hexbin)
  # }

  #############################################




  #
  #
  # tryCatch({
  #   library(DiagrammeR)
  # }, error = function(e) {
  #   install.packages("DiagrammeR")
  #   library(DiagrammeR)
  # })
  #
  #
  # if("DiagrammeR" %in% installed.packages()[,1]){
  #   library(DiagrammeR)
  # }else{
  #   install.packages("DiagrammeR")
  #   library(DiagrammeR)
  # }

  #############################################





  #############################################




  #
  #
  # tryCatch({
  #   library( rmarkdown)
  # }, error = function(e) {
  #   install.packages("rmarkdown")
  #   library( rmarkdown)
  # })
  #
  #
  # if(" rmarkdown" %in% installed.packages()[,1]){
  #   library( rmarkdown)
  # }else{
  #   install.packages("rmarkdown")
  #   library( rmarkdown)
  # }

  #############################################





















}#function -----------------------------------------------------
